Glossary — Transifex v0.8.0 documentation

# Transifex v0.8.0 documentation

# Glossary

I18n
  I18n is the common abbreviation for Internationalization.
Internationalization
  Internationalization is the process of designing a software application so that it can be adapted to various languages and regions without engineering changes.
L10n
  L10N is the common abbreviation for Localization.
Localization
  Localization is the process of adapting software for a specific region or language by adding locale-specific components and translating text.
project
  A project in Transifex represents a software package which is usually stored on a VCS repository. A project repository might include multiple translatable resources like documentation and UI, and also ship multiple branches of its code.
slug

  A short label for something, containing only letters, numbers, underscores or hyphens. They’re generally used in URLs. For example, in a typical Transifex project URL:

      http://www.transifex.net/anaconda/

  the last bit (`anaconda`) is the slug.

VCS
  A Version Control System (also known as source control/code management) is a system used to manage multiple revisions of the same unit of information. Examples of VCS systems include Bazaar, CVS, Git, Mercurial and Subversion.